# Dira ProSuite Python Client

## Functionality

The Dira ProSuite Python Client is the Python API for the ProSuite Quality Verification Server. ProSuite is a suite of high-end productivity tools for ArcGIS for data production, quality assurance, and cartographic refinement.

The ProSuite Python Client API is a lightweight package that provides access to the ProSuite QA functionality. It has been specifically designed as an easy-to-use programming interface that supports intellisense and comes with a documentation and samples.
Quality specifications containing QA tests for geodata can be fully defined in Python and executed on a ProSuite server which runs either locally or on a remote machine. Alternatively, an existing XML specification can be executed with just a few lines of code.

Find out more about ProSuite at [Dira GeoSystems](https://dirageosystems.ch/prosuite).

## Installation
``pip install prosuite``

## Documentation
See [ProSuite Python](https://dirageosystems.ch/prosuite/doc/api).
